aboutsummaryrefslogtreecommitdiffstats
path: root/engine/pokemon/add_mon.asm
diff options
context:
space:
mode:
authorSylvie <35663410+Rangi42@users.noreply.github.com>2024-08-04 10:05:33 -0400
committerGitHub <noreply@github.com>2024-08-04 10:05:33 -0400
commit77d051479bd0ed96cc2efdba52f837afd1e119c3 (patch)
tree72a22aeb8dd6edc10323f0ee72fe9dbf73e5481a /engine/pokemon/add_mon.asm
parentIdentify wcd6d as wNameBuffer and others (#455) (diff)
downloadpokeyellow-77d051479bd0ed96cc2efdba52f837afd1e119c3.tar.gz
pokeyellow-77d051479bd0ed96cc2efdba52f837afd1e119c3.tar.xz
pokeyellow-77d051479bd0ed96cc2efdba52f837afd1e119c3.zip
Identify wcf91 as wCurPartySpecies, wCurItem, and wCurListMenuItem (#457)
Diffstat (limited to 'engine/pokemon/add_mon.asm')
-rw-r--r--engine/pokemon/add_mon.asm14
1 files changed, 7 insertions, 7 deletions
diff --git a/engine/pokemon/add_mon.asm b/engine/pokemon/add_mon.asm
index 73ba8071..ab167a24 100644
--- a/engine/pokemon/add_mon.asm
+++ b/engine/pokemon/add_mon.asm
@@ -21,7 +21,7 @@ _AddPartyMon::
jr nc, .noCarry
inc d
.noCarry
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
ld [de], a ; write species of new mon in party list
inc de
ld a, $ff ; terminator
@@ -64,7 +64,7 @@ _AddPartyMon::
ld e, l
ld d, h
push hl
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
ld [wd0b5], a
call GetMonHeader
ld hl, wMonHeader
@@ -80,7 +80,7 @@ _AddPartyMon::
jr nz, .next4
; If the mon is being added to the player's party, update the pokedex.
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
ld [wd11e], a
push de
predef IndexToPokedex
@@ -275,7 +275,7 @@ AddPartyMon_WriteMovePP:
jr nz, .pploop ; there are still moves to read
ret
; adds enemy mon [wcf91] (at position [wWhichPokemon] in enemy list) to own party
; used in the cable club trade center
_AddEnemyMonToPlayerParty::
ld hl, wPartyCount
@@ -288,7 +288,7 @@ _AddEnemyMonToPlayerParty::
ld c, a
ld b, $0
add hl, bc
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
ld [hli], a ; add mon as last list entry
ld [hl], $ff ; write new sentinel
ld hl, wPartyMons
@@ -322,7 +322,7 @@ _AddEnemyMonToPlayerParty::
call SkipFixedLengthTextEntries
ld bc, NAME_LENGTH
call CopyData ; write new mon's nickname (from an enemy mon)
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
ld [wd11e], a
predef IndexToPokedex
ld a, [wd11e]
@@ -371,7 +371,7 @@ _MoveMon::
cp DAYCARE_TO_PARTY
ld a, [wDayCareMon]
jr z, .copySpecies
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
.copySpecies
ld [hli], a ; write new mon ID
ld [hl], $ff ; write new sentinel
@@ -275,7 +275,7 @@ AddPartyMon_WriteMovePP:
jr nz, .pploop ; there are still moves to read
ret
-; adds enemy mon [wcf91] (at position [wWhichPokemon] in enemy list) to own party
+; adds enemy mon [wCurPartySpecies] (at position [wWhichPokemon] in enemy list) to own party
; used in the cable club trade center
_AddEnemyMonToPlayerParty::